@@ -28,40 +28,25 @@
 
 This AWS Solutions Construct implements an Amazon API Gateway REST API connected to Amazon DynamoDB table.
 
-Here is a minimal deployable pattern definition in:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
 import { ApiGatewayToDynamoDBProps, ApiGatewayToDynamoDB } from "@aws-solutions-constructs/aws-apigateway-dynamodb";
 
 new ApiGatewayToDynamoDB(this, 'test-api-gateway-dynamodb-default', {});
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_apigateway_dynamodb import ApiGatewayToDynamoDB
-from aws_cdk import Stack
-from constructs import Construct
-
-ApiGatewayToDynamoDB(self, 'test-api-gateway-dynamodb-default')
+```text
+new ApiGatewayToDynamoDB(scope: Construct, id: string, props: ApiGatewayToDynamoDBProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awsconstructs.services.apigatewaydynamodb.*;
-
-new ApiGatewayToDynamoDB(this, "test-api-gateway-dynamodb-default", new ApiGatewayToDynamoDBProps.Builder()
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`ApiGatewayToDynamoDBProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -117,7 +102,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -129,19 +114,17 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_iam
 import aws_cdk.aws_logs
-import aws_cdk.core
+import constructs
 
 
 class ApiGatewayToDynamoDB(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-apigateway-dynamodb.ApiGatewayToDynamoDB",
 ):
@@ -151,19 +134,19 @@ class ApiGatewayToDynamoDB(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         allow_create_operation: typing.Optional[builtins.bool] = None,
         allow_delete_operation: typing.Optional[builtins.bool] = None,
         allow_read_operation: typing.Optional[builtins.bool] = None,
         allow_update_operation: typing.Optional[builtins.bool] = None,
-        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
         create_request_template: typing.Optional[builtins.str] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
         read_request_template: typing.Optional[builtins.str] = None,
         update_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -187,28 +170,6 @@ class ApiGatewayToDynamoDB(
         :since: 0.8.0
         :summary: Constructs a new instance of the ApiGatewayToDynamoDB class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                allow_create_operation: typing.Optional[builtins.bool] = None,
-                allow_delete_operation: typing.Optional[builtins.bool] = None,
-                allow_read_operation: typing.Optional[builtins.bool] = None,
-                allow_update_operation: typing.Optional[builtins.bool] = None,
-                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
-                create_request_template: typing.Optional[builtins.str] = None,
-                delete_request_template: typing.Optional[builtins.str] = None,
-                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-                existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                read_request_template: typing.Optional[builtins.str] = None,
-                update_request_template: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToDynamoDBProps(
             allow_create_operation=allow_create_operation,
             allow_delete_operation=allow_delete_operation,
@@ -226,27 +187,27 @@ class ApiGatewayToDynamoDB(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayRole")
     def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayRole"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> aws_cdk.aws_dynamodb.Table:
         return typing.cast(aws_cdk.aws_dynamodb.Table, jsii.get(self, "dynamoTable"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
     def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
         return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
@@ -278,12 +239,12 @@ class ApiGatewayToDynamoDBProps:
         allow_delete_operation: typing.Optional[builtins.bool] = None,
         allow_read_operation: typing.Optional[builtins.bool] = None,
         allow_update_operation: typing.Optional[builtins.bool] = None,
-        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
         create_request_template: typing.Optional[builtins.str] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
         read_request_template: typing.Optional[builtins.str] = None,
         update_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -309,36 +270,6 @@ class ApiGatewayToDynamoDBProps:
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
-        if __debug__:
-            def stub(
-                *,
-                allow_create_operation: typing.Optional[builtins.bool] = None,
-                allow_delete_operation: typing.Optional[builtins.bool] = None,
-                allow_read_operation: typing.Optional[builtins.bool] = None,
-                allow_update_operation: typing.Optional[builtins.bool] = None,
-                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
-                create_request_template: typing.Optional[builtins.str] = None,
-                delete_request_template: typing.Optional[builtins.str] = None,
-                dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
-                existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                read_request_template: typing.Optional[builtins.str] = None,
-                update_request_template: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument allow_create_operation", value=allow_create_operation, expected_type=type_hints["allow_create_operation"])
-            check_type(argname="argument allow_delete_operation", value=allow_delete_operation, expected_type=type_hints["allow_delete_operation"])
-            check_type(argname="argument allow_read_operation", value=allow_read_operation, expected_type=type_hints["allow_read_operation"])
-            check_type(argname="argument allow_update_operation", value=allow_update_operation, expected_type=type_hints["allow_update_operation"])
-            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
-            check_type(argname="argument create_request_template", value=create_request_template, expected_type=type_hints["create_request_template"])
-            check_type(argname="argument delete_request_template", value=delete_request_template, expected_type=type_hints["delete_request_template"])
-            check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
-            check_type(argname="argument existing_table_obj", value=existing_table_obj, expected_type=type_hints["existing_table_obj"])
-            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
-            check_type(argname="argument read_request_template", value=read_request_template, expected_type=type_hints["read_request_template"])
-            check_type(argname="argument update_request_template", value=update_request_template, expected_type=type_hints["update_request_template"])
         self._values: typing.Dict[str, typing.Any] = {}
         if allow_create_operation is not None:
             self._values["allow_create_operation"] = allow_create_operation
